==> haskell-constraints-0.14.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints
version:              0.14.1
visibility:           public
id:                   constraints-0.14.1-1tsSwlSGMMdBVecBo79j8K
key:                  constraints-0.14.1-1tsSwlSGMMdBVecBo79j8K
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2021 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/constraints/
synopsis:             Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.

    This package provides a vocabulary for working with them.

category:             Constraints
abi:                  e88466c2e94c1ac63526812bf43eccbe
exposed:              True
exposed-modules:
    Data.Constraint Data.Constraint.Char Data.Constraint.Deferrable
    Data.Constraint.Forall Data.Constraint.Lifting Data.Constraint.Nat
    Data.Constraint.Symbol Data.Constraint.Unsafe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/constraints-0.14.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/constraints-0.14.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/constraints-0.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints
hs-libraries:         HSconstraints-0.14.1-1tsSwlSGMMdBVecBo79j8K
depends:
    base-4.17.2.1 binary-0.8.9.1 boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb mtl-2.2.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html:         /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.14.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints
version:              0.14.1
visibility:           public
id:                   constraints-0.14.1-CNfpiPG5aaXLI96OZk219s
key:                  constraints-0.14.1-CNfpiPG5aaXLI96OZk219s
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2021 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/constraints/
synopsis:             Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.

    This package provides a vocabulary for working with them.

category:             Constraints
abi:                  2e047f73b77627ec12fb1cdad1e3c0b9
exposed:              True
exposed-modules:
    Data.Constraint Data.Constraint.Char Data.Constraint.Deferrable
    Data.Constraint.Forall Data.Constraint.Lifting Data.Constraint.Nat
    Data.Constraint.Symbol Data.Constraint.Unsafe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/constraints-0.14.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/constraints-0.14.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/constraints-0.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints
hs-libraries:         HSconstraints-0.14.1-CNfpiPG5aaXLI96OZk219s
depends:
    base-4.17.2.1 binary-0.8.9.1 boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.4.0-KHdv63hvW7JkoOGsLWKac mtl-2.2.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html:         /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
